Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(969)

Unified Diff: ui/native_theme/overlay_scrollbar_constants_aura.h

Issue 2816923002: change overlay scrollbar hover show to hover fade in (Closed)
Patch Set: merge kOverlayScrollbarFadeInDelay and kOverlayScrollbarFadeOutDelay to kOverlayScrollbarFadeDelay Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/native_theme/overlay_scrollbar_constants_aura.h
diff --git a/ui/native_theme/overlay_scrollbar_constants_aura.h b/ui/native_theme/overlay_scrollbar_constants_aura.h
index a6192d902249f49721dd6162b35e642024bc9f1e..feb344d704cc7136d76b009a15aca08d4fa9852b 100644
--- a/ui/native_theme/overlay_scrollbar_constants_aura.h
+++ b/ui/native_theme/overlay_scrollbar_constants_aura.h
@@ -18,13 +18,11 @@ constexpr float kOverlayScrollbarThumbHoverAlpha = 0.7f;
constexpr float kOverlayScrollbarStrokeNormalAlpha = 0.3f;
constexpr float kOverlayScrollbarStrokeHoverAlpha = 0.5f;
-// kOverlayScrollbarShowDelay is only for the case where the mouse hovers near
-// the screen edge.
-constexpr base::TimeDelta kOverlayScrollbarShowDelay =
+// kOverlayScrollbarFadeDelay is for the case where the mouse hovers near
+// the screen edge and no scroll action for a while.
Evan Stade 2017/04/20 14:33:45 nit: the wording of this comment is a little confu
+constexpr base::TimeDelta kOverlayScrollbarFadeDelay =
base::TimeDelta::FromMilliseconds(1000);
-constexpr base::TimeDelta kOverlayScrollbarFadeOutDelay =
- base::TimeDelta::FromMilliseconds(1000);
-constexpr base::TimeDelta kOverlayScrollbarFadeOutDuration =
+constexpr base::TimeDelta kOverlayScrollbarFadeDuration =
base::TimeDelta::FromMilliseconds(200);
// TODO(bokan): This is still undetermined. crbug.com/652520.
constexpr base::TimeDelta kOverlayScrollbarThinningDuration =

Powered by Google App Engine
This is Rietveld 408576698